@@ -34,7 +34,7 @@ import (
 var localServerListCmd = &console.Command{
 	Category: "local",
 	Name:     "server:list",
-	Aliases:  []*console.Alias{{Name: "server:list"}},
+	Aliases:  []*console.Alias{{Name: "server:list"}, {Name: "server:ls"}},
 	Usage:    "List all configured local web servers",
 	Action: func(c *console.Context) error {
 		return printConfiguredServers()
